@@ -1,6 +1,6 @@
 package Log::Unrotate;
 BEGIN {
-  $Log::Unrotate::VERSION = '1.24';
+  $Log::Unrotate::VERSION = '1.25';
 }
 
 use strict;
@@ -14,7 +14,7 @@ Log::Unrotate - Reader of rotated logs.
 
 =head1 VERSION
 
-version 1.24
+version 1.25
 
 =head1 SYNOPSIS
 
@@ -291,8 +291,7 @@ sub _reopen ($$;$$)
 
         my @stat = stat $FILE;
         return 0 if $from == 0 and $stat[7] < $position;
-        return 0 if $stat[7] == 0 and $self->{LogNumber} == 0 and $self->{end} eq 'fixed';
-        seek $FILE, $position, $from;
+        return 0 if $stat[7] == 0 and $self->{LogNumber} == 0 and $self->{end} eq 'fixed'; seek $FILE, $position, $from;
         $self->{Handle} = $FILE;
         $self->{Inode} = $stat[1];
         return 1;
@@ -459,6 +458,26 @@ sub lag ($)
     return $lag;
 }
 
+=item B<< log_number() >>
+
+Get current log number.
+
+=cut
+sub log_number {
+    my ($self) = @_;
+    return $self->{LogNumber};
+}
+
+=item B<< log_name() >>
+
+Get current log name. Don't contain C<< .N >> postfix even if cursor points to old log file.
+
+=cut
+sub log_name {
+    my ($self) = @_;
+    return $self->{log};
+}
+
 =back
 
 =head1 BUGS & CAVEATS
